Plug-in Classes
===============


Fleur input generator plug-in
+++++++++++++++++++++++++++++


Fleurinputgen Calculation
-------------------------
.. automodule:: aiida.orm.calculation.job.fleur_inp.fleurinputgen
   :members:

Fleurinputgen Parser
--------------------
.. automodule:: aiida.parsers.plugins.fleur_inp.fleur_inputgen
   :members:


Fleur input Data structure
++++++++++++++++++++++++++


FleurinpData
------------
.. automodule:: aiida.orm.data.fleurinp
   :members:
   :special-members: __init__

.. automodule:: aiida.orm.data.fleurinp.fleurinpmodifier
   :members:

Fleur plug-in
+++++++++++++

Fleur Calculation
-----------------
.. automodule:: aiida.orm.calculation.job.fleur_inp.fleur
   :members:

Fleur Parser
------------
.. automodule:: aiida.parsers.plugins.fleur_inp.fleur
   :members:

Fleur tools/utility
===================

StructureData utility
+++++++++++++++++++++

.. automodule:: aiida.tools.codespecific.fleur.StructureData_util
   :members:

XML utility
+++++++++++

.. automodule:: aiida.tools.codespecific.fleur.xml_util
   :members:

ParameterData utility
+++++++++++++++++++++
.. automodule:: aiida.tools.codespecific.fleur.merge_parameter
   :members:
